@@ -1,44 +1,56 @@
 var NAVTREEINDEX5 =
 {
-"pipewire_8c.html#ad6b599f28dfb2e60a14ac4cf01d4c18c":[11,0,50,9],
+"permission_8h.html#aa6b729cf828ec6417f5ba997560fda2b":[11,0,49,9],
+"permission_8h_source.html":[11,0,49],
+"pipewire_8c.html":[11,0,50],
+"pipewire_8c.html#a5432ea68283040ae9df24ebefe6414aa":[11,0,50,5],
+"pipewire_8c.html#aa060eea150eca4951bf30b2738493912":[11,0,50,10],
+"pipewire_8c.html#abfa925ac473c041c452e6d2287e77776":[11,0,50,9],
+"pipewire_8c.html#ac0edd7fd875859cef79624861e212cc8":[11,0,50,8],
+"pipewire_8c.html#acbb97d3ccaef2d8793ec48242324bf15":[11,0,50,12],
+"pipewire_8c.html#ad6b599f28dfb2e60a14ac4cf01d4c18c":[11,0,50,11],
+"pipewire_8c.html#adc79f7ce98fb706a36eb8a32de61b20c":[11,0,50,7],
+"pipewire_8c.html#add0a31293ff259daa9029be346321392":[11,0,50,6],
 "pipewire_8c.html#ae55b0f7a82aa61d5eb34593565176036":[11,0,50,4],
 "pipewire_8h.html":[11,0,51],
-"pipewire_8h.html#a06c879b2d800579f4724109054368d99":[11,0,51,8],
-"pipewire_8h.html#a0a42d8f153fc58df733f74e5bf9af251":[11,0,51,6],
-"pipewire_8h.html#a0b5efe6f38693683c07c4495bfcce6c4":[11,0,51,7],
-"pipewire_8h.html#a4a582dbda1862c28b2eb70f50696cfc3":[11,0,51,5],
-"pipewire_8h.html#a4efeba27bea1dc8d9188b8e49b3bd1b0":[11,0,51,1],
-"pipewire_8h.html#a5cb61aa7df1b5fc780b2df1dd1d576b6":[11,0,51,4],
-"pipewire_8h.html#a7f855ab509d6e01e13cf561968a4d1b6":[11,0,51,2],
+"pipewire_8h.html#a06c879b2d800579f4724109054368d99":[11,0,51,10],
+"pipewire_8h.html#a0a42d8f153fc58df733f74e5bf9af251":[11,0,51,7],
+"pipewire_8h.html#a0b5efe6f38693683c07c4495bfcce6c4":[11,0,51,8],
+"pipewire_8h.html#a245d94286ccbb5c23cec4448cc7070f0":[11,0,51,9],
+"pipewire_8h.html#a4a582dbda1862c28b2eb70f50696cfc3":[11,0,51,6],
+"pipewire_8h.html#a4efeba27bea1dc8d9188b8e49b3bd1b0":[11,0,51,2],
+"pipewire_8h.html#a5cb61aa7df1b5fc780b2df1dd1d576b6":[11,0,51,5],
+"pipewire_8h.html#a7f855ab509d6e01e13cf561968a4d1b6":[11,0,51,3],
 "pipewire_8h.html#acc287aaae982260a49eeac97f27a8227":[11,0,51,0],
-"pipewire_8h.html#accacb9b931e5e7d72c02987939f4edfd":[11,0,51,9],
-"pipewire_8h.html#ae5e843dfd1edbf7204e6b40bbeb590a2":[11,0,51,3],
-"pipewire_8h.html#af3d7686492ea5032eb135cddf21d3da2":[11,0,51,10],
+"pipewire_8h.html#accacb9b931e5e7d72c02987939f4edfd":[11,0,51,11],
+"pipewire_8h.html#ae5e843dfd1edbf7204e6b40bbeb590a2":[11,0,51,4],
+"pipewire_8h.html#af3d7686492ea5032eb135cddf21d3da2":[11,0,51,12],
+"pipewire_8h.html#afa6045cd7391b467af4575c6752d6c4e":[11,0,51,1],
 "pipewire_8h_source.html":[11,0,51],
 "port_8h.html":[11,0,52],
-"port_8h.html#a08be9849ba07abfd630fcc2b9094e132":[11,0,52,17],
-"port_8h.html#a0a2b3393a17045c7f8a6ff004c8c7f33":[11,0,52,11],
-"port_8h.html#a0f310d02527226da27151627692f999b":[11,0,52,8],
-"port_8h.html#a1ed9c2e11f128b205fa467a2c0f19fe1":[11,0,52,13],
-"port_8h.html#a2d08d6e2358afc05ca212a0258fb6a26":[11,0,52,19],
-"port_8h.html#a32a9f01e1dde49d9c5b6f64efe7af6e5":[11,0,52,18],
-"port_8h.html#a3e912fde083fd69eca50d503c041eabb":[11,0,52,9],
-"port_8h.html#a5c505757aec81210eabf84b1f9593e70":[11,0,52,12],
-"port_8h.html#a65cece0b739dc2a020a9ded0b26a22a3":[11,0,52,14],
-"port_8h.html#a6ab4af1a18861478a1a9c24f3f59ea79":[11,0,52,22],
-"port_8h.html#a6e316525982a94659dfd8b86d9090c02":[11,0,52,5],
-"port_8h.html#a6e9e847059d68cbdb608abc8eb6b631d":[11,0,52,21],
-"port_8h.html#a6e9e847059d68cbdb608abc8eb6b631da056778b9306610d7070ea4c3cc260c53":[11,0,52,21,0],
-"port_8h.html#a6e9e847059d68cbdb608abc8eb6b631da08983f9bf02a2e66e0ea838631d64ebe":[11,0,52,21,1],
-"port_8h.html#a7458b44dfe9ccfb564276d814a49e94a":[11,0,52,20],
-"port_8h.html#a866d33374688faec738124490db2877e":[11,0,52,7],
-"port_8h.html#a9ca65febfd5440fa24c17ae89da5c0bd":[11,0,52,10],
-"port_8h.html#ac5541bb77b42b3e6d41d4ee9b4c06b6f":[11,0,52,3],
-"port_8h.html#ac556c0b1548946709e9e99daa8b52b1b":[11,0,52,6],
-"port_8h.html#ad14c54cfcc288a9b8b8f01fe54a86a5d":[11,0,52,16],
-"port_8h.html#ada3484ae34475c97571c091b7494d7b3":[11,0,52,15],
-"port_8h.html#adfbc0811753d8dface115a011a356360":[11,0,52,23],
-"port_8h.html#af355e07f1fb54c06af8e1040c47bd1c3":[11,0,52,4],
+"port_8h.html#a08be9849ba07abfd630fcc2b9094e132":[11,0,52,20],
+"port_8h.html#a0a2b3393a17045c7f8a6ff004c8c7f33":[11,0,52,14],
+"port_8h.html#a0f310d02527226da27151627692f999b":[11,0,52,11],
+"port_8h.html#a1ed9c2e11f128b205fa467a2c0f19fe1":[11,0,52,16],
+"port_8h.html#a2d08d6e2358afc05ca212a0258fb6a26":[11,0,52,22],
+"port_8h.html#a32a9f01e1dde49d9c5b6f64efe7af6e5":[11,0,52,21],
+"port_8h.html#a3e912fde083fd69eca50d503c041eabb":[11,0,52,12],
+"port_8h.html#a5c505757aec81210eabf84b1f9593e70":[11,0,52,15],
+"port_8h.html#a65cece0b739dc2a020a9ded0b26a22a3":[11,0,52,17],
+"port_8h.html#a6ab4af1a18861478a1a9c24f3f59ea79":[11,0,52,24],
+"port_8h.html#a6e316525982a94659dfd8b86d9090c02":[11,0,52,8],
+"port_8h.html#a7458b44dfe9ccfb564276d814a49e94a":[11,0,52,23],
+"port_8h.html#a866d33374688faec738124490db2877e":[11,0,52,10],
+"port_8h.html#a9ca65febfd5440fa24c17ae89da5c0bd":[11,0,52,13],
+"port_8h.html#ab2082f9bafca5d7d9ff6c53fb3431823":[11,0,52,3],
+"port_8h.html#ac245481d75b73061398575ed44ab3e07":[11,0,52,5],
+"port_8h.html#ac5541bb77b42b3e6d41d4ee9b4c06b6f":[11,0,52,6],
+"port_8h.html#ac556c0b1548946709e9e99daa8b52b1b":[11,0,52,9],
+"port_8h.html#ac8fe785592185f71666d2d03903cc367":[11,0,52,4],
+"port_8h.html#ad14c54cfcc288a9b8b8f01fe54a86a5d":[11,0,52,19],
+"port_8h.html#ada3484ae34475c97571c091b7494d7b3":[11,0,52,18],
+"port_8h.html#adfbc0811753d8dface115a011a356360":[11,0,52,25],
+"port_8h.html#af355e07f1fb54c06af8e1040c47bd1c3":[11,0,52,7],
 "port_8h_source.html":[11,0,52],
 "properties_8c.html":[11,0,53],
 "properties_8c.html#a45bb0212063f3daf407c3896f376e7b3":[11,0,53,0],
@@ -66,10 +78,10 @@ var NAVTREEINDEX5 =
 "protocol_8c.html#a36b16ebb431f39b8439ca456bec7fe87":[11,0,55,1],
 "protocol_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,55,0],
 "protocol_8c.html#a7321365269fdc141a1995b2df56161c6":[11,0,55,5],
+"protocol_8c.html#a8cd83927fc5105e58443dcd0f74bddff":[11,0,55,6],
 "protocol_8c.html#a9638585c7880eb5dad87cc14c68cf509":[11,0,55,9],
 "protocol_8c.html#adaa5ef11c165140322c7f6af484ddccf":[11,0,55,3],
 "protocol_8c.html#adacff2f9c7a8c1022b1111d9ecfea7d2":[11,0,55,2],
-"protocol_8c.html#ae7f582f72d189d3117e666992f7e38f5":[11,0,55,6],
 "protocol_8c.html#af1ff8145055154bee0c4bd8db6310c46":[11,0,55,10],
 "protocol_8h.html":[11,0,56],
 "protocol_8h.html#a0026bb6385904327d20a8dfcf982ba62":[11,0,56,6],
@@ -100,10 +112,11 @@ var NAVTREEINDEX5 =
 "protocol_8h_source.html":[11,0,56],
 "proxy_8c.html":[11,0,57],
 "proxy_8c.html#a0230e50305d6532135262f047d78d589":[11,0,57,8],
+"proxy_8c.html#a040756d38e9005b9e0594d3b577a71c6":[11,0,57,15],
 "proxy_8c.html#a052431961e2ec5f5c2d6281371b51d76":[11,0,57,14],
 "proxy_8c.html#a069f5c4b4ce0b793cae45f42a80402f4":[11,0,57,5],
 "proxy_8c.html#a23bac343d4e384a18a2af8309c45427c":[11,0,57,12],
-"proxy_8c.html#a24a682b4ae829a3df5b15d81413117b7":[11,0,57,15],
+"proxy_8c.html#a24a682b4ae829a3df5b15d81413117b7":[11,0,57,16],
 "proxy_8c.html#a2991ce1ad533d4538c1ff0319040ca97":[11,0,57,13],
 "proxy_8c.html#a300bdaa7161aa447a4eba6a739715352":[11,0,57,9],
 "proxy_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,57,0],
@@ -111,13 +124,13 @@ var NAVTREEINDEX5 =
 "proxy_8c.html#a6224e5d633541e2b174202a2cce954f4":[11,0,57,10],
 "proxy_8c.html#a67e58eecfbb34d685afa175730bf6b48":[11,0,57,6],
 "proxy_8c.html#a975552b85dda76a790be32704f7039c8":[11,0,57,7],
+"proxy_8c.html#a99c20bae91db208101db6c41eb1ba3f3":[11,0,57,11],
 "proxy_8c.html#aa1ffe7f68e1007f515834cd60d7f38a0":[11,0,57,4],
-"proxy_8c.html#ab78447e86c8400d4837f02aecbd1b76c":[11,0,57,18],
-"proxy_8c.html#ac3860a60d2600abb6808ba5241df7f3a":[11,0,57,17],
+"proxy_8c.html#ab78447e86c8400d4837f02aecbd1b76c":[11,0,57,19],
+"proxy_8c.html#ac3860a60d2600abb6808ba5241df7f3a":[11,0,57,18],
 "proxy_8c.html#ac3f1077584142c2fa0648fa89179d85f":[11,0,57,3],
-"proxy_8c.html#ac598b9d43036d387eae8f88840767cf8":[11,0,57,16],
+"proxy_8c.html#ac598b9d43036d387eae8f88840767cf8":[11,0,57,17],
 "proxy_8c.html#acde8eeec95cd202da19496a6416d5b46":[11,0,57,2],
-"proxy_8c.html#aed8e622832732068c10e12f165b3c7be":[11,0,57,11],
 "proxy_8h.html":[11,0,58],
 "proxy_8h.html#a00ecf59a7b69d43ae4106312174d709b":[11,0,58,19],
 "proxy_8h.html#a01735abb03506ca5b939744c2679e8ae":[11,0,58,5],
@@ -142,6 +155,7 @@ var NAVTREEINDEX5 =
 "proxy_8h_source.html":[11,0,58],
 "resource_8c.html":[11,0,59],
 "resource_8c.html#a0d95e95f9b243ccfb01d72a4b830b723":[11,0,59,12],
+"resource_8c.html#a2f7b9147420545849b8dfe0854571ca6":[11,0,59,14],
 "resource_8c.html#a3a9a54881991621284af6adaddbe8fc3":[11,0,59,5],
 "resource_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,59,0],
 "resource_8c.html#a51c7cc27c6480a9f90aa46f682f78fbb":[11,0,59,18],
@@ -161,7 +175,6 @@ var NAVTREEINDEX5 =
 "resource_8c.html#ae7534e38e4825d07fe8330fa99f6fb62":[11,0,59,13],
 "resource_8c.html#af2660cf560a8b1df8d6dab389ab22d1f":[11,0,59,16],
 "resource_8c.html#afd32e674691ae1c261494fb1e177e550":[11,0,59,1],
-"resource_8c.html#afd6d8e65f061b5168ab5081cab747527":[11,0,59,14],
 "resource_8h.html":[11,0,60],
 "resource_8h.html#a119a41be865f03ef8736977acba8a323":[11,0,60,5],
 "resource_8h.html#a11df048744c827fbefc328ec7b9dc135":[11,0,60,2],
@@ -189,36 +202,35 @@ var NAVTREEINDEX5 =
 "resource_8h.html#af8fe4859dd6826d5eb6c7e28f5519215":[11,0,60,13],
 "resource_8h_source.html":[11,0,60],
 "stream_8c.html":[11,0,61],
-"stream_8c.html#a0995f39a36edfc2c7db6b041eae8007e":[11,0,61,22],
-"stream_8c.html#a0aa398ef7b09697a0e48719b27112614":[11,0,61,28],
-"stream_8c.html#a0d2ad73d654de2bc11afe6847474afcb":[11,0,61,35],
+"stream_8c.html#a0aa398ef7b09697a0e48719b27112614":[11,0,61,27],
+"stream_8c.html#a0d2ad73d654de2bc11afe6847474afcb":[11,0,61,34],
 "stream_8c.html#a1676b48e222d9bcf50fd21374ea121c2":[11,0,61,6],
-"stream_8c.html#a1ffbabb0a49127dc56c22e466c2903e7":[11,0,61,24],
-"stream_8c.html#a272af3c2d61d7fb25dc2ab076dc044de":[11,0,61,17],
-"stream_8c.html#a2ab8d1619a5739153a3bff01e6c6788e":[11,0,61,25],
+"stream_8c.html#a1f024c54b2e507824ea0f5441f5b2af4":[11,0,61,32],
+"stream_8c.html#a1ffbabb0a49127dc56c22e466c2903e7":[11,0,61,23],
+"stream_8c.html#a272af3c2d61d7fb25dc2ab076dc044de":[11,0,61,16],
+"stream_8c.html#a2ab8d1619a5739153a3bff01e6c6788e":[11,0,61,24],
 "stream_8c.html#a40ad70cc6e2125af9340a4bc26a83764":[11,0,61,10],
 "stream_8c.html#a41326ea19a5ae0815a63f0db0a114dfc":[11,0,61,8],
-"stream_8c.html#a430884fd1ac91c74cb5574400a619216":[11,0,61,18],
-"stream_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,61,12],
-"stream_8c.html#a49bc4fcdc6924fbb895066dc4bda8559":[11,0,61,11],
-"stream_8c.html#a4ce79c03126c9b7166c33cab212283ce":[11,0,61,21],
-"stream_8c.html#a54dfe4670ac6de650a3926b68cadbdb8":[11,0,61,27],
-"stream_8c.html#a664d10ae36c157ecca989fe0c562017b":[11,0,61,23],
+"stream_8c.html#a430884fd1ac91c74cb5574400a619216":[11,0,61,17],
+"stream_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,61,11],
+"stream_8c.html#a4ce79c03126c9b7166c33cab212283ce":[11,0,61,20],
+"stream_8c.html#a54dfe4670ac6de650a3926b68cadbdb8":[11,0,61,26],
+"stream_8c.html#a65b66a8987387a5894d8414e9573a880":[11,0,61,21],
+"stream_8c.html#a664d10ae36c157ecca989fe0c562017b":[11,0,61,22],
 "stream_8c.html#a7781bc9613ec655352585fb1bac2595d":[11,0,61,9],
-"stream_8c.html#a7d77dd629b7e3a8c6d28cccb93df21e4":[11,0,61,29],
+"stream_8c.html#a7d77dd629b7e3a8c6d28cccb93df21e4":[11,0,61,28],
 "stream_8c.html#a89bba79201856c41ea53bd01e65f6438":[11,0,61,7],
-"stream_8c.html#a93f84e7cab1f289398e277aec50a63b8":[11,0,61,16],
-"stream_8c.html#ab41e1c2fa4274c6916e51655e481dd6e":[11,0,61,34],
-"stream_8c.html#ac1d281db6111363227781192d2eb56c7":[11,0,61,32],
-"stream_8c.html#ac930a5d7e17ec3cd1d48fa5b3d671c7c":[11,0,61,33],
-"stream_8c.html#ac9d87c5da34f1357637309ffdd1185cb":[11,0,61,20],
-"stream_8c.html#ad05e907fadaaa1cd21062cd0bb8701a1":[11,0,61,30],
-"stream_8c.html#ad5e65901bc4e01fe66908de6eb983b74":[11,0,61,19],
-"stream_8c.html#ae19fa7dc034a052b0ee1f582e8a949c0":[11,0,61,13],
-"stream_8c.html#ae8a3753316267cd885e875ae7fbd3c91":[11,0,61,26],
-"stream_8c.html#aebbd77924da3cf1c98f8552178f42da6":[11,0,61,15],
-"stream_8c.html#af86bc65adf0e4c18f8ea3c09f5e62d9d":[11,0,61,31],
-"stream_8c.html#afeafcb95f3bc48b81410bf7848473a8f":[11,0,61,14],
+"stream_8c.html#a93f84e7cab1f289398e277aec50a63b8":[11,0,61,15],
+"stream_8c.html#ab41e1c2fa4274c6916e51655e481dd6e":[11,0,61,33],
+"stream_8c.html#ac1d281db6111363227781192d2eb56c7":[11,0,61,31],
+"stream_8c.html#ac9d87c5da34f1357637309ffdd1185cb":[11,0,61,19],
+"stream_8c.html#ad05e907fadaaa1cd21062cd0bb8701a1":[11,0,61,29],
+"stream_8c.html#ad5e65901bc4e01fe66908de6eb983b74":[11,0,61,18],
+"stream_8c.html#ae19fa7dc034a052b0ee1f582e8a949c0":[11,0,61,12],
+"stream_8c.html#ae8a3753316267cd885e875ae7fbd3c91":[11,0,61,25],
+"stream_8c.html#aebbd77924da3cf1c98f8552178f42da6":[11,0,61,14],
+"stream_8c.html#af86bc65adf0e4c18f8ea3c09f5e62d9d":[11,0,61,30],
+"stream_8c.html#afeafcb95f3bc48b81410bf7848473a8f":[11,0,61,13],
 "stream_8h.html":[11,0,62],
 "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106":[11,0,62,5],
 "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b":[11,0,62,5,2],
@@ -237,17 +249,5 @@ var NAVTREEINDEX5 =
 "stream_8h.html#a55c1224289e488e27f8d3b6e58abcd08":[11,0,62,17],
 "stream_8h.html#a5ef987fd1903baa7eba9b10a8cbf5e97":[11,0,62,9],
 "stream_8h.html#a751f41a0a5ce1ece31ec126b3cab4fd4":[11,0,62,11],
-"stream_8h.html#a7a8eafa174549733293f11ec2c646827":[11,0,62,14],
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82":[11,0,62,6],
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82a0537b5f9f722fb2faf7822cd09370825":[11,0,62,6,3],
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82a775f5777259aa54f7ad6d4c7cfa1779f":[11,0,62,6,2],
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82aae02f4af09cb65c931e95e1aa3bdd5f3":[11,0,62,6,1],
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82aae3c1d061da27957fd3a9389b29ff89e":[11,0,62,6,0],
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82af3c3b39039810d40a7c9e1ae3c6c905d":[11,0,62,6,4],
-"stream_8h.html#ab2ef0e28a1e91816f8015ef9814d18f7":[11,0,62,8],
-"stream_8h.html#abe1c593f34080ea9c8c6231abe4e7386":[11,0,62,15],
-"stream_8h.html#adfa74620109228a9cfce24b628aa130f":[11,0,62,7],
-"stream_8h.html#aeb58b45b3e0d8fa804e9165d32159aa2":[11,0,62,10],
-"stream_8h.html#af21c1b002f78067d2eca97c455970822":[11,0,62,4],
-"stream_8h.html#afc74d20ae2305d82aba860fde41b9e31":[11,0,62,12]
+"stream_8h.html#a7a8eafa174549733293f11ec2c646827":[11,0,62,14]
 };
